# Ferris

A simple Slack client for Ruby

```ruby
#!/usr/bin/env ruby
require 'ferris'

TOKEN, CHANNEL = '...', '...'

# Interact with the Real-Time Messaging API
rtm = Ferris::RTM.new token: TOKEN

# Interact with the regular API methods
api = Ferris::API.new token: TOKEN

# Callback for messages from the RTM API
rtm.on :message do |m|
  puts m
end

# Add as many callbacks as you like, they'll
# each get a copy of incoming messages
rtm.on :message do |m|
  $stderr.puts message: m
end

rtm.go # Start the RTM API worker in the background

# The RTM API allows you to send basic messages
# See https://api.slack.com/rtm for docs
rtm.send 'message', \
  channel: CHANNEL, text: 'Hello from the RTM API'

rtm.send 'ping' # Send "ping" and get back "pong"

# Use the regular API for advanced scenarios (e.g. attachments)
# See https://api.slack.com/methods for docs
api.send 'chat.postMessage', \
  channel: CHANNEL, text: 'Hello from the regular API'

rtm.join # Bring the RTM API worker into the foreground

rtm.kill # We'll never reach here...
```